<?php

  /**
   * @file
   * Admin page callback file for the cmood module.
   */

  /**
   * Page callback: Generates the appropriate mood administration form.
   *
   * This function generates the CURD operations for cmood module
   *
   * @return string
   *   A renderable form array for the respective request.
   */
  function cmood_admin() {
    $header = array(
      array('data' => t('WID'), 'field' => 'wid', 'sort' => 'asc'),
      array('data' => t('Word'), 'field' => 'name'),
      array('data' => t('Weight'), 'field' => 'weight'),
      array('data' => t('UID'), 'field' => 'uid'),
      array('data' => t('Created'), 'field' => 'created'),
      array('data' => t('Updated'), 'field' => 'updated'),
    );
    $rows = array();
    $query = db_select('word_with_weight', 'www')->fields('www');
    $table_sort = $query->extend('TableSort')
      ->orderByHeader($header);
    $pager = $table_sort->extend('PagerDefault')
      ->limit(10);
    $results = $pager->execute();
    foreach ($results as $key => $row) {
      $rows[] = array($row->wid,
        $row->name,
        $row->weight,
        $row->uid,
        l('edit', 'admin/cmood/' . $row->wid . '/edit'),
        l('delete', 'admin/cmood/' . $row->wid . '/delete'),
      );
    }
    $link_word = l('Add Mood Word', 'admin/cmood/word/add');
    $links_word_rank = l('Manage Rank Words', 'admin/cmood/rank_words');
    return $link_word . " " . $links_word_rank . theme('table', 
      array('header' => $header, 'rows' => $rows)) . theme('pager');
  }

  /**
   * Page callback: Generates the appropriate rank word administration form.
   *
   * This function generates the CURD operations for cmood module
   *
   * @return string
   *   A renderable form array for the respective request.
   */
  function cmood_rank_words() {
    $header = array(
      array('data' => t('RWID'), 'field' => 'rwid', 'sort' => 'asc'),
      array('data' => t('Word'), 'field' => 'name'),
      array('data' => t('Weight'), 'field' => 'weight'),
      array('data' => t('UID'), 'field' => 'uid'),
      array('data' => t('Created'), 'field' => 'created'),
      array('data' => t('Updated'), 'field' => 'updated'),
    );
    $rows = array();
    $query = db_select('rank_word_with_weight', 'rwww')->fields('rwww');
    $table_sort = $query->extend('TableSort')
      ->orderByHeader($header);
    $pager = $table_sort->extend('PagerDefault')
      ->limit(10);
    $results = $pager->execute();
    foreach ($results as $key => $row) {
      $rows[] = array($row->rwid,
        $row->name,
        $row->weight,
        $row->uid,
        l('edit', 'admin/cmood/rank_word/' . $row->rwid . '/edit'),
        l('delete', 'admin/cmood/rank_word/' . $row->rwid . '/delete'),
      );
    }
    $link_word = l('Manage Mood Word', 'admin/cmood/words');
    $links_word_rank = l('Add Rank Word', 'admin/cmood/rank_word/add');
    return $link_word . " " . $links_word_rank . theme('table', 
      array('header' => $header, 'rows' => $rows)) . theme('pager');
  }

  function cmood_node_mood_listing() {
    $header = array(
      array('data' => t('ID'), 'field' => 'id', 'sort' => 'asc'),
      array('data' => t('Node Title'), 'field' => 'title'),
      array('data' => t('Node Mood'), 'field' => 'mood'),
    );
    $rows = array();
    $query = db_select('node_mood', 'nm')
      ->fields('nm', array('id', 'nid', 'mood'))
      ->fields('n', array('title'));
    $query->join('node', 'n', 'nm.nid = n.nid');
    $table_sort = $query->extend('TableSort')
      ->orderByHeader($header);
    $pager = $table_sort->extend('PagerDefault')
      ->limit(10);
    $results = $pager->execute();
    foreach ($results as $key => $row) {
      $title = (strlen($row->title) > 30) ? substr($row->title, 0, 30) . '...' : $row->title;
      $rows[] = array($row->id,
        $title,
        $row->mood,
      );
    }
    $link_word = l('Manage Mood Word', 'admin/cmood/words');
    $links_word_rank = l('Manage Rank Word', 'admin/cmood/rank_words');
    return $link_word . " " . $links_word_rank . theme('table', 
      array('header' => $header, 'rows' => $rows)) . theme('pager');
  }
  